@@ -14,6 +14,8 @@
 #' @param brace.newline whether to put the left brace \code{\{} to a new line
 #'   (default \code{FALSE})
 #' @param indent number of spaces to indent the code (default 4)
+#' @param wrap whether to wrap comments to the linewidth determined by
+#'   \code{width.cutoff} (note that roxygen comments will never be wrapped)
 #' @param output output to the console or a file using \code{\link{cat}}?
 #' @param text an alternative way to specify the input: if it is \code{NULL},
 #'   the function will read the source code from the \code{source} argument;
@@ -30,11 +32,12 @@
 #'   character vector} \item{text.mask}{the code containing comments, which are
 #'   masked in assignments or with the weird operator}
 #' @note Be sure to read the reference to know other limitations.
-#' @author Yihui Xie <\url{http://yihui.name}> with substantial contribution
+#' @author Yihui Xie <\url{https://yihui.name}> with substantial contribution
 #'   from Yixuan Qiu <\url{http://yixuan.cos.name}>
 #' @seealso \code{\link{parse}}, \code{\link{deparse}}
-#' @references \url{http://yihui.name/formatR} (an introduction to this package,
-#'   with examples and further notes)
+#' @references \url{https://yihui.name/formatR} (an introduction to this
+#'   package, with examples and further notes)
+#' @import utils
 #' @export
 #' @example inst/examples/tidy.source.R
 tidy_source = function(
@@ -43,63 +46,16 @@ tidy_source = function(
   arrow = getOption('formatR.arrow', FALSE),
   brace.newline = getOption('formatR.brace.newline', FALSE),
   indent = getOption('formatR.indent', 4),
+  wrap = getOption('formatR.wrap', TRUE),
   output = TRUE, text = NULL,
   width.cutoff = getOption('width'), ...
 ) {
-  # compatibility with formatR <= v0.10
-  if (is.logical(getOption('keep.comment'))) {
-    warning("The option 'keep.comment' is deprecated; please use 'formatR.comment'")
-    options(formatR.comment = getOption('keep.comment'))
-  }
-  if (is.logical(getOption('keep.blank.line'))) {
-    warning("The option 'keep.blank.line' is deprecated; please use 'formatR.blank'")
-    options(formatR.blank = getOption('keep.blank.line'))
-  }
-  if (is.logical(getOption('replace.assign'))) {
-    warning("The option 'replace.assign' is deprecated; please use 'formatR.arrow'")
-    options(formatR.arrow = getOption('replace.assign'))
-  }
-  if (is.logical(getOption('left.brace.newline'))) {
-    warning("The option 'left.brace.newline' is deprecated; please use 'formatR.brace.newline'")
-    options(formatR.brace.newline = getOption('left.brace.newline'))
-  }
-  if (is.numeric(getOption('reindent.spaces'))) {
-    warning("The option 'reindent.spaces' is deprecated; please use 'formatR.indent'")
-    options(formatR.indent = getOption('reindent.spaces'))
-  }
-  extra = list(...)
-  if (is.logical(extra$keep.comment)) {
-    warning("The argument 'keep.comment' is deprecated; please use 'comment'")
-    comment = extra$keep.comment
-    extra$keep.comment = NULL
-  }
-  if (is.logical(extra$keep.blank.line)) {
-    warning("The argument 'keep.blank.line' is deprecated; please use 'blank'")
-    blank = extra$keep.blank.line
-    extra$keep.blank.line = NULL
-  }
-  if (is.logical(extra$replace.assign)) {
-    warning("The argument 'replace.assign' is deprecated; please use 'arrow'")
-    arrow = extra$replace.assign
-    extra$replace.assign = NULL
-  }
-  if (is.logical(extra$left.brace.newline)) {
-    warning("The argument 'left.brace.newline' is deprecated; please use 'brace.newline'")
-    brace.newline = extra$left.brace.newline
-    extra$left.brace.newline = NULL
-  }
-  if (is.numeric(extra$reindent.spaces)) {
-    warning("The argument 'reindent.spaces' is deprecated; please use 'indent'")
-    indent = extra$reindent.spaces
-    extra$reindent.spaces = NULL
-  }
-
   if (is.null(text)) {
     if (source == 'clipboard' && Sys.info()['sysname'] == 'Darwin') {
       source = pipe('pbpaste')
     }
   } else {
-    source = textConnection(text); on.exit(close(source))
+    source = textConnection(text); on.exit(close(source), add = TRUE)
   }
   text = readLines(source, warn = FALSE)
   if (length(text) == 0L || all(grepl('^\\s*$', text))) {
@@ -111,14 +67,15 @@ tidy_source = function(
     n1 = attr(regexpr('^\n*', one), 'match.length')
     n2 = attr(regexpr('\n*$', one), 'match.length')
   }
-  if (comment) text = mask_comments(text, width.cutoff, blank)
+  on.exit(.env$line_break <- NULL, add = TRUE)
+  if (comment) text = mask_comments(text, width.cutoff, blank, wrap)
   text.mask = tidy_block(text, width.cutoff, arrow && length(grep('=', text)))
   text.tidy = if (comment) unmask_source(text.mask) else text.mask
   text.tidy = reindent_lines(text.tidy, indent)
   if (brace.newline) text.tidy = move_leftbrace(text.tidy)
   # restore new lines in the beginning and end
   if (blank) text.tidy = c(rep('', n1), text.tidy, rep('', n2))
-  if (output) do.call(cat, c(list(paste(text.tidy, collapse = '\n'), '\n'), extra))
+  if (output) cat(text.tidy, sep = '\n', ...)
   invisible(list(text.tidy = text.tidy, text.mask = text.mask))
 }
 
@@ -141,11 +98,13 @@ tidy_block = function(text, width = getOption('width'), arrow = FALSE) {
 # Restore the real source code from the masked text
 unmask_source = function(text.mask) {
   if (length(text.mask) == 0) return(text.mask)
+  m = .env$line_break
+  if (!is.null(m)) text.mask = gsub(m, '\n', text.mask)
   ## if the comments were separated into the next line, then remove '\n' after
   ##   the identifier first to move the comments back to the same line
   text.mask = gsub('%InLiNe_IdEnTiFiEr%[ ]*\n', '%InLiNe_IdEnTiFiEr%', text.mask)
   ## move 'else ...' back to the last line
-  text.mask = gsub('\n\\s*else', ' else', text.mask)
+  text.mask = gsub('\n\\s*else(\\s+|$)', ' else\\1', text.mask)
   if (any(grepl('\\\\\\\\', text.mask)) &&
       (any(grepl(mat.comment, text.mask)) || any(grepl(inline.comment, text.mask)))) {
     m = gregexpr(mat.comment, text.mask)
@@ -154,26 +113,27 @@ unmask_source = function(text.mask) {
     regmatches(text.mask, m) = lapply(regmatches(text.mask, m), restore_bs)
   }
   text.tidy = gsub(pat.comment, '', text.mask)
-  # inline comments should be termined by $ or \n
+  # inline comments should be terminated by $ or \n
   text.tidy = gsub(paste(inline.comment, '(\n|$)', sep = ''), '  \\1\\2', text.tidy)
   # the rest of inline comments should be appended by \n
   gsub(inline.comment, '  \\1\n', text.tidy)
 }
 
 
-#' Format the R scripts under a directory
+#' Format all R scripts under a directory, or specified R scripts
 #'
-#' This function first looks for all the R scripts under a directory (using the
-#' pattern \code{"[.][RrSsQq]$"}), then uses \code{\link{tidy_source}} to tidy
-#' these scripts. The original scripts will be overwritten with reformatted code
-#' if reformatting was successful. You may need to back up the original
-#' directory first if you do not fully understand the tricks
-#' \code{\link{tidy_source}} is using.
+#' \code{tidy_dir()} first looks for all the R scripts under a directory (using
+#' the pattern \code{"[.][RrSsQq]$"}), then uses \code{\link{tidy_source}} to
+#' tidy these scripts. The original scripts will be overwritten with reformatted
+#' code if reformatting was successful. You may need to back up the original
+#' directory first if you do not fully understand the tricks used by
+#' \code{\link{tidy_source}}. \code{tidy_file()} formats specified R scripts.
 #' @param path the directory
 #' @param recursive whether to recursively look for R scripts under \code{path}
 #' @param ... other arguments to be passed to \code{\link{tidy_source}}
+#' @param file a vector of filenames
 #' @return Invisible \code{NULL}.
-#' @author Yihui Xie <\url{http://yihui.name}>
+#' @author Yihui Xie (\code{tidy_dir}) and Ed Lee (\code{tidy_file})
 #' @seealso \code{\link{tidy_source}}
 #' @export
 #' @examples
@@ -183,9 +143,16 @@ unmask_source = function(text.mask) {
 #' file.copy(system.file('demo', package = 'base'), path, recursive=TRUE)
 #' tidy_dir(path, recursive=TRUE)
 tidy_dir = function(path = '.', recursive = FALSE, ...) {
-  flist = list.files(path, pattern = '[.][RrSsQq]$', full.names = TRUE, recursive = recursive)
-  for (f in flist) {
-    message('tidying ', f)
+  tidy_file(list.files(
+    path, pattern = '[.][RrSsQq]$', full.names = TRUE, recursive = recursive
+  ), ...)
+}
+
+#' @export
+#' @rdname tidy_dir
+tidy_file = function(file, ...) {
+  for (f in file) {
+    message("tidying ", f)
     try(tidy_source(f, file = f, ...))
   }
 }
